@@ -21,27 +21,27 @@ def command_line():
     containing parsed values.
     '''
     description = 'Kan helps you find the book'
-    version = ' '.join([__version__, __release__])
-    parser  = ArgumentParser(prog='kan', description=description)
+    version     = ' '.join([__version__, __release__])
+    parser      = ArgumentParser(prog='kan', description=description)
+
+    subparser   = parser.add_subparsers(help='Search by')
+
+    by_title    = subparser.add_parser('title', help='Book title',)
+    by_title.add_argument('title', help='Book name')
+
+    by_isbn     = subparser.add_parser('isbn', help='ISBN code')
+    by_isbn.add_argument('code', help='Valid ISBN code')
+
+    by_author   = subparser.add_parser('author', help='Book author')
+    by_author.add_argument('author', help='Authors name')
+    by_author.add_argument('--recent', help='Search by most recent', action='store_true')
+    by_author.add_argument('--top', help='Search by best selling', action='store_true')
+
+    # Main Parser
     parser.add_argument(
         '-v', '--version', action='version',
         version="%s v%s" % ('kan', version),
     )
-
-    subparser = parser.add_subparsers(help='Search by')
-
-    bytitle = subparser.add_parser('title', help='Book title',)
-    bytitle.add_argument('title', help='Book name')
-
-    byisbn = subparser.add_parser('isbn', help='ISBN code')
-    byisbn.add_argument('code', help='Valid ISBN code')
-
-    byauthor = subparser.add_parser('author', help='Book author')
-    byauthor.add_argument('author', help='Authors name')
-    byauthor.add_argument('--recent', help='Search by most recent', action='store_true')
-    byauthor.add_argument('--top', help='Search by best selling', action='store_true')
-
-    # Main Parser
     parser.add_argument(
         '--title',
         help='Title of the book',
@@ -74,6 +74,12 @@ def command_line():
         default='',
         help='Restrict the search results to those with a certain language code',
     )
+    parser.add_argument(
+        '--verbose',
+        action='store_true',
+        help='Print out debug information',
+    )
+
     return parser.parse_args()
 
 
@@ -89,8 +95,14 @@ def main():
         author=args.author,
         max_results=args.max,
         language_code=args.language,
+        fields=('title', 'authors', 'imageLinks', 'categories', 'description'),
     )
 
+    if args.verbose:
+        print('Request URL:')
+        print(query.url)
+        print(query.__dict__)
+
     # Temporary Display Interface
     books = query.json.get('items', None)
     if not books:
@@ -99,12 +111,13 @@ def main():
     for book in books:
         info = book['volumeInfo']
 
+        # Retrieve ISBN/Reference Info
         if 'industryIdentifiers' in info:
             identifiers = dict([(ref['type'], ref['identifier']) for ref in info['industryIdentifiers']])
 
+            # Prefer ISBN 13 over ISBN 10
             if 'ISBN_13' in identifiers:
                 isbn_id, isbn = 'ISBN_13', identifiers['ISBN_13']
-
             else:
                 isbn_id, isbn = identifiers.popitem()
 
@@ -118,4 +131,5 @@ def main():
             isbn_id=isbn_id,
             isbn=isbn,
         )
+
         print(display)
