@@ -47,7 +47,7 @@ class AbstractBaseAPIClient:
         """
         return
 
-    @abstractmethod
+    @abstractproperty
     def reader(self):
         """
         Reads content.
@@ -62,25 +62,24 @@ class GoogleBooksAPIClient(AbstractBaseAPIClient):
     Implements the AbstractBaseAPIClient and talks to the google books
     api for querying and finding books.
 
-    :return self: **GoogleBooksAPIClient<self>**
+    :param title: str
+    :param author: str
+    :param max_results: int
+    :param start_index: int
+    :param language_code: str
+    :param fields: tuple
+
+    :return self: **GoogleBooksAPIClient**
     """
 
     def __init__(self,
-        title='',
-        author='',
-        max_results=10,
-        start_index=0,
-        language_code='',
-        fields=('authors', 'title', 'industryIdentifiers'),
-    ):
-        """
-        :param: title: str
-        :param: author: str
-        :param: max_results: int
-        :param: start_index: int
-        :param: language_code: str
-        :param: fields: tuple
-        """
+                 title='',
+                 author='',
+                 max_results=10,
+                 start_index=0,
+                 language_code='',
+                 fields=tuple(),
+        ):
         self.title = title
         self.author = author
         self.max_results = max_results
@@ -107,9 +106,10 @@ class GoogleBooksAPIClient(AbstractBaseAPIClient):
             'langRestrict': self.language_code,
         })
 
+        # Optimizes amount of data requested
         fieldstring = 'fields={prefix}({fields})'.format(
             prefix='/'.join(['items', 'volumeInfo']),
-            fields=','.join(self.fields),
+            fields=','.join(('authors', 'title', 'industryIdentifiers') + self.fields),
         )
 
         return '&'.join(['?'.join([base, params]), fieldstring])
